# Reference

Technical reference material including APIs and release notes.

```{toctree}
:maxdepth: 1
:glob:
reference/*
```

```{toctree}
API <_api/maaspower>
genindex
Release Notes <https://github.com/gilesknap/maaspower/releases>
```
